Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(468)

Unified Diff: base/trace_event/malloc_dump_provider.cc

Issue 1641513004: Update //base to chromium 9659b08ea5a34f889dc4166217f438095ddc10d2 (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/trace_event/BUILD.gn ('k') | base/trace_event/memory_allocator_dump.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/trace_event/malloc_dump_provider.cc
diff --git a/base/trace_event/malloc_dump_provider.cc b/base/trace_event/malloc_dump_provider.cc
index 92d513f99d3e311bef9aecce5d3a186736a78957..4304f280760146bacaa8b2d9dada81878c1a778e 100644
--- a/base/trace_event/malloc_dump_provider.cc
+++ b/base/trace_event/malloc_dump_provider.cc
@@ -32,14 +32,13 @@ bool MallocDumpProvider::OnMemoryDump(ProcessMemoryDump* pmd) {
struct mallinfo info = mallinfo();
DCHECK_GE(info.arena + info.hblkhd, info.uordblks);
// When the system allocator is implemented by tcmalloc, the total physical
// size is given by |arena| and |hblkhd| is 0. In case of Android's jemalloc
// |arena| is 0 and the outer pages size is reported by |hblkhd|. In case of
// dlmalloc the total is given by |arena| + |hblkhd|.
// For more details see link: http://goo.gl/fMR8lF.
MemoryAllocatorDump* outer_dump = pmd->CreateAllocatorDump("malloc");
- outer_dump->AddScalar(MemoryAllocatorDump::kNameSize,
- MemoryAllocatorDump::kUnitsBytes,
+ outer_dump->AddScalar("heap_virtual_size", MemoryAllocatorDump::kUnitsBytes,
info.arena + info.hblkhd);
// Total allocated space is given by |uordblks|.
« no previous file with comments | « base/trace_event/BUILD.gn ('k') | base/trace_event/memory_allocator_dump.h » ('j') | no next file with comments »
@@ -32,14 +32,13 @@ bool MallocDumpProvider::OnMemoryDump(ProcessMemoryDump* pmd) {
struct mallinfo info = mallinfo();
DCHECK_GE(info.arena + info.hblkhd, info.uordblks);
- // When the system allocator is implemented by tcmalloc, the total physical
+ // When the system allocator is implemented by tcmalloc, the total heap
// size is given by |arena| and |hblkhd| is 0. In case of Android's jemalloc
// |arena| is 0 and the outer pages size is reported by |hblkhd|. In case of

Powered by Google App Engine
This is Rietveld 408576698